Learn R Programming

retimer (version 0.1.3)

extractWord: extractWord

Description

Extract from a wav file with reference to a TextGrid.

Usage

extractWord(
  x,
  word,
  tier = "Word",
  ignore_case = TRUE,
  instance = "random",
  wd = getwd()
)

Value

Extracts section of wav file corresponding to word and saves in format name_wordi.wav where name is the original name, word is the word and x is the numeric instance.

Arguments

x

path to a TextGrid

word

word to search for

tier

name of word tier in TextGrid

ignore_case

default is `TRUE`

instance

instance of word in TextGrid to extract. Default extracts a random instance. Can also be numeric (row number)

wd

working directory for Praat to use. Accepts relative paths.

See Also

density