Calculates low frequency power spectrogram of vocalic interval of speech signal. Following method of Tilsen & Johnson (2008)
fft_spectro(x, f_out = 80, window_size = 256, padding = 2048, plot = TRUE)Returns a tibble with frequency (Hz), time (s) and power
a `tuneR` "Wave" object or the path to a .wav file.
the sample frequency for the output
number of samples to calculate each spectrum over
length to zero pad signal to. If signal is longer than padding, this will be increased.
if true a spectrogram will be plotted
Tilsen, S., & Johnson, K. (2008). Low-frequency Fourier analysis of speech rhythm. The Journal of the Acoustical Society of America, 124(2), EL34–EL39. doi:10.1121/1.2947626
fft_spectrum