Learn R Programming

retimer (version 0.1.3)

findPeak: findPeak

Description

Find the mode of numeric vector using the peak of its density distribution.

Usage

findPeak(x, ...)

Value

Returns the value of `x` that corresponds to the peak of the density curve.

Arguments

x

a numeric vector

...

further arguements to be passed to `density`

See Also

density