Universal spectrogram function.
spectrogram(
x,
fs = NULL,
method = NULL,
output = "tibble",
wintime = 25,
steptime = 10
)Returns a spectrogram in the desired format
a signal, `tuneR` WAVE object, or the path to an .wav or .mp3 file.
sample rate if supplying the signal as a vector
spectrogram implementation to use. Available options are 'phonTools', 'tuneR', 'gsignal', and 'seewave'. Default is to select the first of these methods that is available.
format of output
length of analysis window in ms
interval between steps in ms