Extract from a wav file with reference to a TextGrid.
extractWord(
x,
word,
tier = "Word",
ignore_case = TRUE,
instance = "random",
wd = getwd()
)Extracts section of wav file corresponding to word and saves in format name_wordi.wav where name is the original name, word is the word and x is the numeric instance.
path to a TextGrid
word to search for
name of word tier in TextGrid
default is `TRUE`
instance of word in TextGrid to extract. Default extracts a random instance. Can also be numeric (row number)
working directory for Praat to use. Accepts relative paths.
density