powered by
Find the mode of numeric vector using the peak of its density distribution.
findPeak(x, ...)
Returns the value of `x` that corresponds to the peak of the density curve.
a numeric vector
further arguements to be passed to `density`
density