Description
Flatten fundamental frequency contour using 'Praat'
Usage
flatF0(wav, .f = findPeak, ...)
Value
Returns a tuneR WAVE object of the input with a flat F0 contour
Arguments
- wav
path to a wav file or a tuneR WAVE object
- .f
function to use to determine pitch. Default is findPeak which finds the mode of the existing pitch contour.
- ...
Additional arguments passed to extractPitchTier